@@ -1,6 +1,7 @@
 from transformers import BertModel, BertTokenizer, BioGptTokenizer, BioGptModel
 import logging
 from torch import nn
+import torch
 from collections import OrderedDict
 from typing import Union
 
@@ -11,49 +12,71 @@ WORKER = 'ModelModule'
 
 
 def construct_model_head(input_size: int, 
-                         hidden_layers: Union[list, None], 
+                         hidden_layers: list, 
                          num_classes: int) -> nn.Sequential:
-        """
-        Construct classifier head layers 
+    """
+    Construct classifier head layers 
 
-        Input:
-            input_size => int
-            hidden_size => if list, layers will be added sequatially based on list order
-            num_classes => int
+    Input:
+        input_size => int
+        hidden_size => if list, layers will be added sequatially based on list order
+        num_classes => int
 
-        Returns:
-            torch.nn.Sequential
-        """
+    Returns:
+        torch.nn.Sequential
+    """
 
-        seq_layers = []
-        layer_num_counter = 1
+    seq_layers = []
+    layer_num_counter = 1
+
+
+    hidden_layers.append(num_classes)
+    
+    
+    for layer in hidden_layers:
+        if layer == 'relu':
+            seq_layers.append((f'out{layer_num_counter}_relu', nn.ReLU()))
+        else:
+            seq_layers.append((f'out{layer_num_counter}_linear', nn.Linear(input_size, layer)))
+            input_size = layer
+    
+        layer_num_counter+=1
+
+    logging.info(f'{WORKER}: Classfication Head Added. Number of Hidden Layers - {len(seq_layers)}. Number of Classes - {num_classes}')
 
     
-
-        if hidden_layers:
-            hidden_layers.append(num_classes)
-        
-        
-        for layer in hidden_layers:
-            if layer == 'relu':
-                seq_layers.append((f'out{layer_num_counter}_relu', nn.ReLU()))
-            else:
-                seq_layers.append((f'out{layer_num_counter}_linear', nn.Linear(input_size, layer)))
-                input_size = layer
-        
-            layer_num_counter+=1
-
-        logging.info(f'{WORKER}: Classfication Head Added. Number of Hidden Layers - {len(seq_layers)}. Number of Classes - {num_classes}')
-
-        
-        return nn.Sequential(OrderedDict(seq_layers))
+    return nn.Sequential(OrderedDict(seq_layers))
 
 
+
+class SimpleNN(nn.Module):
+    def __init__(self, 
+            input_size,
+            hidden_layers: list,
+            output_size
             
+                ):
+        
+        logging.info(f'{WORKER}: Simple Pytorch NN initiating...')
+
+        super(SimpleNN, self).__init__()
+
+        self.network = construct_model_head(input_size, hidden_layers, output_size)
+
+        logging.info(f'{WORKER}: Simple Pytorch NN Initiated..')
+
+
+    def forward(self, x):
+        
+        outputs = self.network(x)
+
+        return outputs
+        
+
     
  
 
-class PytorchNlpModel(nn.Module):
+class TransformerNN(nn.Module):
     def __init__(self, 
                  pretrained_type: str, 
                  pretrained_path: str, 
@@ -77,8 +100,8 @@ class PytorchNlpModel(nn.Module):
         
         """
         
-        logging.info(f'{WORKER}: PytorchNlpModel initiating...')
-        super(PytorchNlpModel, self).__init__()
+        logging.info(f'{WORKER}: TransformerNN initiating...')
+        super(TransformerNN, self).__init__()
         self.pretrained_type = pretrained_type
 
         if pretrained_type == 'BERT':
@@ -93,7 +116,6 @@ class PytorchNlpModel(nn.Module):
         self.freeze_pretrained = freeze_pretrained
         self.drop = nn.Dropout(p=0.3)
         self.n_classes = n_classes
-        print(head_hidden_layers)
         self.head = construct_model_head(self.pretrained.config.hidden_size,
                                       head_hidden_layers,
                                       self.n_classes)
@@ -101,7 +123,7 @@ class PytorchNlpModel(nn.Module):
             for param in self.pretrained.parameters():
                 param.requires_grad = False
                 
-        logging.info(f'{WORKER}: PytorchNlpModel of type {pretrained_type} with classification head initiated.')
+        logging.info(f'{WORKER}: TransformerNN of type {pretrained_type} with classification head initiated.')
         logging.info(f'{WORKER}: pretrained model freezed - {freeze_pretrained}')
 
     
@@ -113,4 +135,40 @@ class PytorchNlpModel(nn.Module):
             outputs = self.head(outputs)
         elif self.pretrained_type == 'BioGPT':
             outputs = self.head(outputs.last_hidden_state[:,0,:])
-        return outputs
\ No newline at end of file
+        return outputs
+    
+
+class EnsembleTransformer(nn.Module):
+
+    def __init__(self,
+                 model1,
+                 model2,
+                 model3,
+                 tokenizer,
+                 hidden_layers: list,
+                 num_classes: int
+
+                 ):
+
+        super(EnsembleTransformer, self).__init__()
+
+
+        self.model1 = model1
+        self.model2 = model2
+        self.model3 = model3
+        self.tokenizer = tokenizer
+
+        self.out = construct_model_head(3 * 768, hidden_layers, num_classes)  
+
+    
+    def forward(self, input_ids, attention_mask):
+        x1 = self.model1(input_ids = input_ids, 
+                         attention_mask = attention_mask)
+        x2 = self.model2(input_ids = input_ids, 
+                         attention_mask = attention_mask)
+        x3 = self.model3(input_ids = input_ids, 
+                         attention_mask = attention_mask)
+
+        x = torch.cat((x1[1], x2[1], x3[1]), dim = 1)
+
+        return self.out(x)
\ No newline at end of file
